"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const sinon_1 = __importDefault(require("sinon"));
const uuid_1 = require("uuid");
const vitest_1 = require("vitest");
const pipeline_js_1 = require("../internal/pipeline.js");
const register_js_1 = require("../internal/register.js");
const testConfigs = {
    registered: true,
    grpcClient: {
        getAttachCommandsByService: () => ({
            active: [],
            paused: [],
        }),
    },
    sessionId: (0, uuid_1.v4)(),
    streamdalUrl: "localhost:8082",
    streamdalToken: "1234",
    serviceName: "test-service",
    pipelineTimeout: "100",
    stepTimeout: "10",
    dryRun: false,
    audiences: [],
};
const testAudience = {
    serviceName: "test-service",
    componentName: "kafka",
    operationType: 1,
    operationName: "kafka-consumer",
};
const testPipeline = {
    id: "7a04056d-52ae-467e-ab43-2a82a2c90284",
    name: "test-pipeline",
    steps: [
        {
            name: "test-step",
            onSuccess: [],
            onFailure: [],
            step: {
                oneofKind: "detective",
                detective: { args: [], type: 1013, path: "object.field" },
            },
        },
    ],
};
const testAttachCommand = {
    command: {
        oneofKind: "attachPipeline",
        attachPipeline: {
            pipeline: testPipeline,
        },
    },
    audience: testAudience,
};
const testDetachCommand = {
    command: {
        oneofKind: "detachPipeline",
        detachPipeline: {
            pipelineId: testPipeline.id,
        },
    },
    audience: testAudience,
};
const testPauseCommand = {
    command: {
        oneofKind: "pausePipeline",
        pausePipeline: {
            pipelineId: testPipeline.id,
        },
    },
    audience: testAudience,
};
const testResumeCommand = {
    command: {
        oneofKind: "resumePipeline",
        resumePipeline: {
            pipelineId: testPipeline.id,
        },
    },
    audience: testAudience,
};
const testAttachCommandByServiceResponse = {
    response: {
        active: [testAttachCommand],
        paused: [],
        wasmModules: { test: { id: "test", bytes: new Uint8Array() } },
    },
};
(0, vitest_1.describe)("pipeline tests", () => {
    (0, vitest_1.it)("initPipelines should add a given pipeline to internal store and set pipelineInitialized ", () => __awaiter(void 0, void 0, void 0, function* () {
        sinon_1.default
            .stub(testConfigs.grpcClient, "getAttachCommandsByService")
            .resolves(testAttachCommandByServiceResponse);
        yield (0, pipeline_js_1.initPipelines)(testConfigs);
        (0, vitest_1.expect)(register_js_1.internal.pipelines.has((0, register_js_1.audienceKey)(testAudience))).toEqual(true);
        (0, vitest_1.expect)(register_js_1.internal.pipelineInitialized).toEqual(true);
    }));
    (0, vitest_1.describe)("processResponse", () => {
        (0, vitest_1.it)("attach command should add pipeline to internal store", () => {
            (0, pipeline_js_1.processResponse)(testAttachCommand);
            (0, vitest_1.expect)(register_js_1.internal.pipelines.has((0, register_js_1.audienceKey)(testAudience))).toEqual(true);
        });
        (0, vitest_1.it)("detach command should remove pipeline from internal store", () => {
            register_js_1.internal.pipelines.set((0, register_js_1.audienceKey)(testAudience), Object.assign(Object.assign({}, testPipeline), { paused: false }));
            (0, pipeline_js_1.processResponse)(testDetachCommand);
            (0, vitest_1.expect)(register_js_1.internal.pipelines.has((0, register_js_1.audienceKey)(testAudience))).toEqual(false);
        });
        (0, vitest_1.it)("pause command should flag pipeline as paused in internal store", () => {
            var _a;
            register_js_1.internal.pipelines.set((0, register_js_1.audienceKey)(testAudience), Object.assign(Object.assign({}, testPipeline), { paused: false }));
            (0, pipeline_js_1.processResponse)(testPauseCommand);
            (0, vitest_1.expect)((_a = register_js_1.internal.pipelines.get((0, register_js_1.audienceKey)(testAudience))) === null || _a === void 0 ? void 0 : _a.paused).toEqual(true);
        });
        (0, vitest_1.it)("resume command should flag pipeline as not paused in internal store", () => {
            var _a;
            register_js_1.internal.pipelines.set((0, register_js_1.audienceKey)(testAudience), Object.assign(Object.assign({}, testPipeline), { paused: false }));
            (0, pipeline_js_1.processResponse)(testResumeCommand);
            (0, vitest_1.expect)((_a = register_js_1.internal.pipelines.get((0, register_js_1.audienceKey)(testAudience))) === null || _a === void 0 ? void 0 : _a.paused).toEqual(false);
        });
    });
});
