"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.runWasm = exports.readResponse = exports.instantiateWasm = void 0;
const sp_wsm_1 = require("@streamdal/protos/protos/sp_wsm");
// eslint-disable-next-line import/no-unresolved
const wasi_1 = require("wasi");
const register_js_1 = require("./register.js");
const [nodeVersionMajor] = process.versions.node.split(".");
const wasi = new wasi_1.WASI(Object.assign(Object.assign({}, (Number(nodeVersionMajor) >= 20 ? { version: "preview1" } : {})), { preopens: {
        "/sandbox": "./",
    } }));
const instantiateWasm = (wasmId, wasmBytes) => __awaiter(void 0, void 0, void 0, function* () {
    if (!wasmId || !wasmBytes || wasmBytes.length === 0) {
        console.debug("Wasm info missing, skipping instantiation, .");
        return;
    }
    if (register_js_1.internal.wasmModules.has(wasmId)) {
        console.debug("Wasm exists, skipping instantiation");
        return;
    }
    const wasm = yield WebAssembly.compile(wasmBytes);
    const importObject = { wasi_snapshot_preview1: wasi.wasiImport };
    register_js_1.internal.wasmModules.set(wasmId, yield WebAssembly.instantiate(wasm, importObject));
});
exports.instantiateWasm = instantiateWasm;
const readResponse = (pointer, buffer) => {
    //
    // Shift right by 32 bits to get the start value
    const start = Number(pointer >> BigInt(32));
    //
    // Bitwise AND operation with 0xFFFFFFFF to get the length
    const length = Number(pointer & BigInt(0xffffffff));
    return buffer.slice(start, start + length);
};
exports.readResponse = readResponse;
const runWasm = ({ step, data, }) => {
    const request = sp_wsm_1.WASMRequest.create({
        step: {
            name: step.name,
            onSuccess: step.onSuccess,
            onFailure: step.onFailure,
            step: step.step,
        },
        inputPayload: data,
    });
    const { exports } = register_js_1.internal.wasmModules.get(step.WasmId);
    const { memory, alloc, [step.WasmFunction]: f } = exports;
    const requestBytes = sp_wsm_1.WASMRequest.toBinary(request);
    const ptr = alloc(requestBytes.length);
    const mem = new Uint8Array(memory.buffer, ptr, requestBytes.length);
    mem.set(requestBytes);
    const returnPtr = BigInt(f(ptr, requestBytes.length));
    const response = (0, exports.readResponse)(returnPtr, new Uint8Array(memory.buffer));
    return sp_wsm_1.WASMResponse.fromBinary(response);
};
exports.runWasm = runWasm;
