var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import sinon from "sinon";
import { v4 as uuidv4 } from "uuid";
import { describe, expect, it } from "vitest";
import { initPipelines, processResponse } from "../internal/pipeline.js";
import { audienceKey, internal } from "../internal/register.js";
const testConfigs = {
    registered: true,
    grpcClient: {
        getAttachCommandsByService: () => ({
            active: [],
            paused: [],
        }),
    },
    sessionId: uuidv4(),
    streamdalUrl: "localhost:8082",
    streamdalToken: "1234",
    serviceName: "test-service",
    pipelineTimeout: "100",
    stepTimeout: "10",
    dryRun: false,
    audiences: [],
};
const testAudience = {
    serviceName: "test-service",
    componentName: "kafka",
    operationType: 1,
    operationName: "kafka-consumer",
};
const testPipeline = {
    id: "7a04056d-52ae-467e-ab43-2a82a2c90284",
    name: "test-pipeline",
    steps: [
        {
            name: "test-step",
            onSuccess: [],
            onFailure: [],
            step: {
                oneofKind: "detective",
                detective: { args: [], type: 1013, path: "object.field" },
            },
        },
    ],
};
const testAttachCommand = {
    command: {
        oneofKind: "attachPipeline",
        attachPipeline: {
            pipeline: testPipeline,
        },
    },
    audience: testAudience,
};
const testDetachCommand = {
    command: {
        oneofKind: "detachPipeline",
        detachPipeline: {
            pipelineId: testPipeline.id,
        },
    },
    audience: testAudience,
};
const testPauseCommand = {
    command: {
        oneofKind: "pausePipeline",
        pausePipeline: {
            pipelineId: testPipeline.id,
        },
    },
    audience: testAudience,
};
const testResumeCommand = {
    command: {
        oneofKind: "resumePipeline",
        resumePipeline: {
            pipelineId: testPipeline.id,
        },
    },
    audience: testAudience,
};
const testAttachCommandByServiceResponse = {
    response: {
        active: [testAttachCommand],
        paused: [],
        wasmModules: { test: { id: "test", bytes: new Uint8Array() } },
    },
};
describe("pipeline tests", () => {
    it("initPipelines should add a given pipeline to internal store and set pipelineInitialized ", () => __awaiter(void 0, void 0, void 0, function* () {
        sinon
            .stub(testConfigs.grpcClient, "getAttachCommandsByService")
            .resolves(testAttachCommandByServiceResponse);
        yield initPipelines(testConfigs);
        expect(internal.pipelines.has(audienceKey(testAudience))).toEqual(true);
        expect(internal.pipelineInitialized).toEqual(true);
    }));
    describe("processResponse", () => {
        it("attach command should add pipeline to internal store", () => {
            processResponse(testAttachCommand);
            expect(internal.pipelines.has(audienceKey(testAudience))).toEqual(true);
        });
        it("detach command should remove pipeline from internal store", () => {
            internal.pipelines.set(audienceKey(testAudience), Object.assign(Object.assign({}, testPipeline), { paused: false }));
            processResponse(testDetachCommand);
            expect(internal.pipelines.has(audienceKey(testAudience))).toEqual(false);
        });
        it("pause command should flag pipeline as paused in internal store", () => {
            var _a;
            internal.pipelines.set(audienceKey(testAudience), Object.assign(Object.assign({}, testPipeline), { paused: false }));
            processResponse(testPauseCommand);
            expect((_a = internal.pipelines.get(audienceKey(testAudience))) === null || _a === void 0 ? void 0 : _a.paused).toEqual(true);
        });
        it("resume command should flag pipeline as not paused in internal store", () => {
            var _a;
            internal.pipelines.set(audienceKey(testAudience), Object.assign(Object.assign({}, testPipeline), { paused: false }));
            processResponse(testResumeCommand);
            expect((_a = internal.pipelines.get(audienceKey(testAudience))) === null || _a === void 0 ? void 0 : _a.paused).toEqual(false);
        });
    });
});
